@@ -5,7 +5,7 @@
 #include <deque>
 #include <string>
 
-using std::cout; using std::cerr;
+using std::cerr;
 using std::endl; using std::string;
 using std::ifstream; using std::vector;
 
@@ -14,7 +14,7 @@ using std::ifstream; using std::vector;
 int main(int argc, char *argv[]){
   std::ios_base::sync_with_stdio(false);
     if (argc >= 1){
-        // std::cout<< argv[1];
+        // //std::cout<< argv[1];
         string filename(argv[1]);
         // vector<char> line;
         std::deque<char> two_characters;
@@ -64,10 +64,10 @@ int main(int argc, char *argv[]){
         bool line_finished = 0;
         // bool accumulating = false;
         std::string result_accumulation = "";
-
+        //std::cout << "starting" << '\n';
 
         while (input_file.get(byte)) {
-            // std::cout << byte;
+            // //std::cout << byte;
             if (two_characters.size() < 2){
 
               two_characters.push_back(byte);
@@ -119,9 +119,11 @@ int main(int argc, char *argv[]){
                         if (character == '\"'){
                             inside_string = 1;
                             fwrite(&character, sizeof(character), 1, stdout );
-                        }else{
+                        }else{                            
                             if (character == ',' || two_characters.front() == '\n'){
+                              //std::cout << "A" << '\n';
                                 if (two_characters.front() == '\n' && character == ','){
+                                  //std::cout << "A.1" << '\n';
                                   if (result_accumulation.size() == 0){
                                     if (character != '\r'){
                                       fwrite(&character, sizeof(character), 1, stdout );
@@ -131,6 +133,9 @@ int main(int argc, char *argv[]){
                                     bool is_nan = false;
                                     for(int i=0;i<nans.size();i++){
                                       is_nan = is_nan || result_accumulation == nans[i];
+                                      if (is_nan){
+                                        break;
+                                      }
                                     }
 
                                     if (is_nan){
@@ -154,15 +159,24 @@ int main(int argc, char *argv[]){
                                     // fields[current_field_index] = '';
                                 }
                                 else if (two_characters.front() == '\n'){
+                                  //std::cout << "A.2" << '\n';
                                   if (result_accumulation.size() == 0){
+                                    //std::cout << "A.2.A" << '\n';
+                                    //std::cout<<character<<'\n';
                                     if (character != '\r'){
                                       fwrite(&character, sizeof(character), 1, stdout );
                                     }
                                   }else{
+                                    //std::cout << "A.2.B" << " " << character<<" "<<result_accumulation.size() << '\n';
+                                    // //std::cout<<character<<" "<<two_characters.front()<<'\n';
+                                    result_accumulation.push_back(character);                                    
                                     int length = result_accumulation.size();
                                     bool is_nan = false;
                                     for(int i=0;i<nans.size();i++){
                                       is_nan = is_nan || result_accumulation == nans[i];
+                                      if (is_nan){
+                                        break;
+                                      }
                                     }
 
                                     if (is_nan){
@@ -174,16 +188,19 @@ int main(int argc, char *argv[]){
                                         }
                                       }
                                       result_accumulation = "";
+                                      if (character != '\r'){
+                                        fwrite(&character, sizeof(character), 1, stdout );
+                                      }
 
                                     }
-                                    if (character != '\r'){
-                                      fwrite(&character, sizeof(character), 1, stdout );
-                                    }
+                                    
                                   }
                                     // fields[current_field_index] = field;
                                     // field = '';
 
                                 }else{
+                                  //std::cout << "A.3" << '\n';
+                                  
                                   if (result_accumulation.size() == 0){
                                     if (character != '\r'){
                                       fwrite(&character, sizeof(character), 1, stdout );
@@ -193,6 +210,9 @@ int main(int argc, char *argv[]){
                                     bool is_nan = false;
                                     for(int i=0;i<nans.size();i++){
                                       is_nan = is_nan || result_accumulation == nans[i];
+                                      if (is_nan){
+                                        break;
+                                      }
                                     }
 
                                     if (is_nan){
@@ -218,11 +238,15 @@ int main(int argc, char *argv[]){
 
 
                             }else{
+                              //std::cout << "C"<<" "<< character<<" "<<result_accumulation.size()<<'\n';
                               if (result_accumulation.size() == 0){
                                 bool is_nan = false;
                                 int length = 1;
                                 for(int i=0;i<nans.size();i++){
                                   is_nan = is_nan || (length <= nans[i].size() && character == nans[i].at(0));
+                                  if (is_nan){
+                                    break;
+                                  }
                                 }
 
                                 if (is_nan){
@@ -240,6 +264,9 @@ int main(int argc, char *argv[]){
                                 bool is_nan = false;
                                 for(int i=0;i<nans.size();i++){
                                   is_nan = is_nan || (length <= nans[i].size() && result_accumulation == nans[i].substr(0,length));
+                                  if (is_nan){
+                                    break;
+                                  }
                                 }
 
                                 if (is_nan){
@@ -302,13 +329,13 @@ int main(int argc, char *argv[]){
                         current_field_index = 1;
                         inside_string = 0;
                         // for (char i : line) {
-                        //     // std::cout << i;
+                        //     // //std::cout << i;
                         //     fwrite(&i, sizeof(i), 1, stdout );
                         // }
                         char c = '\n';
                         fwrite(&c, sizeof(c), 1, stdout );
-                        // std::cout<<'\n';
-                        // std::cout<< line.size();
+                        // //std::cout<<'\n';
+                        // //std::cout<< line.size();
                         // cout << endl;
 
                         // cout << &line;
@@ -364,7 +391,9 @@ int main(int argc, char *argv[]){
                 fwrite(&character, sizeof(character), 1, stdout );
             }else{
                 if (character == ',' || two_characters.front() == '\n'){
+                  //std::cout<<"last-A"<<'\n';
                     if (two_characters.front() == '\n' && character == ','){
+                      //std::cout<<"last-A1"<<'\n';
                         fwrite(&character, sizeof(character), 1, stdout );
                         // fields[current_field_index] = field;
                         // field = '';
@@ -372,6 +401,7 @@ int main(int argc, char *argv[]){
                         // fields[current_field_index] = '';
                     }
                     else if (two_characters.front() == '\n'){
+                        //std::cout<<"last-A2"<<'\n';
                         if (character != '\r'){
                           fwrite(&character, sizeof(character), 1, stdout );
                         }
@@ -379,6 +409,7 @@ int main(int argc, char *argv[]){
                         // field = '';
 
                     }else{
+                      //std::cout<<"last-A3"<<'\n';
                         if (character != '\r'){
                           fwrite(&character, sizeof(character), 1, stdout );
                         }
@@ -390,20 +421,57 @@ int main(int argc, char *argv[]){
 
 
                 }else{
-                    if (character != '\r'){
-                      fwrite(&character, sizeof(character), 1, stdout );
+                  //std::cout<<"last-B"<<'\n';
+                    // if (character != '\r'){
+                    //   fwrite(&character, sizeof(character), 1, stdout );
+                    // }
+                    if (result_accumulation.size() == 0){
+                      //std::cout << "A.2.A" << '\n';
+                      //std::cout<<character<<'\n';
+                      if (character != '\r'){
+                        fwrite(&character, sizeof(character), 1, stdout );
+                      }
+                    }else{
+                      //std::cout << "A.2.B" << " " << character<<" "<<result_accumulation.size() << '\n';
+                      // //std::cout<<character<<" "<<two_characters.front()<<'\n';
+                      result_accumulation.push_back(character);                                    
+                      int length = result_accumulation.size();
+                      bool is_nan = false;
+                      for(int i=0;i<nans.size();i++){
+                        is_nan = is_nan || result_accumulation == nans[i];
+                        if (is_nan){
+                          break;
+                        }
+                      }
+
+                      if (is_nan){
+                          result_accumulation = "";
+                      }else{
+                        for (char char_ : result_accumulation){
+                          if (char_ != '\r'){
+                            fwrite(&char_, sizeof(char_), 1, stdout );
+                          }
+                        }
+                        result_accumulation = "";
+                        if (character != '\r'){
+                          fwrite(&character, sizeof(character), 1, stdout );
+                        }
+
+                      }
+                      
                     }
+                    
                 }
             }
 
         }
         // for (char i : line) {
-        //     // std::cout << i;
+        //     // //std::cout << i;
         //     fwrite(&i, sizeof(i), 1, stdout );
         // }
         c = '\n';
         fwrite(&c, sizeof(c), 1, stdout );
-        // std::cout<< line.size();
+        // //std::cout<< line.size();
         // cout << endl;
         // fwrite( &line, sizeof(line), 1, stdout );
         // cout << &line;
